@@ -10,6 +10,7 @@ from django.shortcuts import render
 from django.utils.datastructures import SortedDict
 from django.utils.importlib import import_module
 from django.views.debug import cleanse_setting
+from django.views.decorators.cache import never_cache
 
 from doctor.conf import TEMPLATE_CONTEXT
 from doctor.services import load_service_classes
@@ -36,16 +37,21 @@ def index(request):
         'services': services,
     })
 
+@never_cache
 def health_check(request):
     """
     Basic health check view, returns plain text response with 200 OK response.
     Useful for external monitor systems.
 
-    TODO: Should we limit this to some extent? (maybe INTERNAL_IPS?)
+    TODO: Actually check all the services before returning OK :)
     """
 
+    # Check for allowed remote IP addresses or superuser status
+    if not request.META.get('REMOTE_ADDR', '') in settings.INTERNAL_IPS:
+        if not request.user.is_superuser:
+            raise Http404('Allowed IP addresses or superusers only.')
+
     response = HttpResponse(content_type='text/plain')
-    response['Cache-Control'] = 'no-cache'
 
     # Generate message and hit the database
     msg = '%(domain)s running on %(socket_name)s is OK at %(datetime)s' % {
@@ -102,7 +108,7 @@ def technical_info(request):
 
 def force_server_error(request):
     """
-    Raises an exception. Useful for testing Sentry, error reporting mails.
+    Raises an exception. Useful for testing Sentry, error reporting mails, etc.
     """
 
     # Reject non-superusers
